{% extends "base.html" %}
{% load django_simple_nav %}
{% block extra_head %}
  <style>
  .active {
    font-weight: bold;
  }
  </style>
{% endblock extra_head %}
{% block nav %}
  {% django_simple_nav "navigation.BasicNav" %}
{% endblock nav %}
