{% extends "base.html" %}
{% load django_simple_nav %}
{% block extra_head %}
  <style>
  [data-foo="bar"] {
    background-color: red;
  }
  </style>
{% endblock extra_head %}
{% block nav %}
  {% django_simple_nav "navigation.ExtraContextNav" %}
{% endblock nav %}
